==> ytree-1.78.tar.gz: ytree-1.78/hex.c <==
/***************************************************************************
 *
 * $Header: /usr/local/cvsroot/utils/ytree/hex.c,v 1.14 2003/04/21 19:56:13 werner Exp $
 *
 * View-Hex-Kommando-Bearbeitung
 *
 ***************************************************************************/


#include "ytree.h"



static int ViewHexFile(char *file_path);
static int ViewHexArchiveFile(char *file_path);



int ViewHex(char *file_path)
{
  switch( mode )
  {
    case DISK_MODE :
    case USER_MODE :     return( ViewHexFile( file_path ) );
    case TAPE_MODE : 
    case RPM_FILE_MODE : 
    case TAR_FILE_MODE : 
    case ZOO_FILE_MODE :
    case ZIP_FILE_MODE :
    case LHA_FILE_MODE :
    case ARC_FILE_MODE : return( ViewHexArchiveFile( file_path ) );
    default:             beep(); return( -1 );
  }
}




static int ViewHexFile(char *file_path)
{
  char *command_line;
  int  compress_method;
  int  result = -1;
  char *hexdump_cmd;


  hexdump_cmd = HEXDUMP;

  if(!strcmp(hexdump_cmd, "builtin")) {
    hexdump_cmd = builtin_hexdump_cmd;
  }


  if( access( file_path, R_OK ) )
  {
    (void) sprintf( message, 
		    "HexView not possible!*\"%s\"*%s", 
		    file_path, 
		    strerror(errno) 
		  );
    MESSAGE( message );
    ESCAPE;
  }

  if( ( command_line = (char *)malloc( COMMAND_LINE_LENGTH + 1 ) ) == NULL )
  {
    ERROR_MSG( "Malloc failed*ABORT" );
    exit( 1 );
  }


  compress_method = GetFileMethod( file_path );


  if( compress_method == FREEZE_COMPRESS )
  {
    (void) sprintf( command_line, 
		    "%s < '%s' %s | %s | %s", 
		    MELT, 
		    file_path, 
		    ERR_TO_STDOUT,
		    hexdump_cmd, 
		    PAGER 
		  );
  }
  else if( compress_method == COMPRESS_COMPRESS )
  {
    (void) sprintf( command_line, 
		    "%s < '%s' %s | %s | %s", 
		    UNCOMPRESS, 
		    file_path, 
		    ERR_TO_STDOUT,
		    hexdump_cmd, 
		    PAGER 
		  );
  }
  else if( compress_method == GZIP_COMPRESS )
  {
    (void) sprintf( command_line, 
		    "%s < '%s' %s | %s | %s", 
		    GNUUNZIP, 
		    file_path, 
		    ERR_TO_STDOUT,
		    hexdump_cmd, 
		    PAGER 
		  );
  }
  else
  {
    (void) sprintf( command_line, 
		    "%s '%s' | %s", 
		    hexdump_cmd, 
		    file_path, 
		    PAGER 
		  );
  }
    
  
  if((result = SystemCall( command_line )))
  {
    (void) sprintf( message, "can't execute*%s", command_line );
    MESSAGE( message );
  }

  free( command_line );

FNC_XIT:

  return( result );
}



static int ViewHexArchiveFile(char *file_path)
{
  char *command_line;
  char *archive;
  char buffer[80];
  int result = -1;
  char *hexdump_cmd;


  hexdump_cmd = HEXDUMP;

  if(!strcmp(hexdump_cmd, "builtin")) {
    hexdump_cmd = builtin_hexdump_cmd;
  }


  if( ( command_line = (char *)malloc( COMMAND_LINE_LENGTH + 1 ) ) == NULL )
  {
    ERROR_MSG( "Malloc failed*ABORT" );
    exit( 1 );
  }

  (void) sprintf( buffer, "| %s | %s", hexdump_cmd, PAGER );

  archive = (mode == TAPE_MODE) ? statistic.tape_name : statistic.login_path;

  MakeExtractCommandLine( command_line, 
			  archive,
			  file_path, 
			  buffer
			);

  if((result = SystemCall( command_line )))
  {
    (void) sprintf( message, "can't execute*%s", command_line );
    MESSAGE( message );
  }

  free( command_line );

  return( result );
}




int BuiltinHexDump(char *file)
{
  char ibuf[32],obuf[128],*p,*pp;
  FILE *ifil;
  int b,cnt;
  long filadr=0L;
  char nibs[]="0123456789ABCDEF";
  int result = -1;

  if(file == NULL || *file == '\0') {
    ifil = stdin;
  } else {
    if( (ifil=fopen(file,"rb"))==NULL)
    {
      (void) fprintf( stderr, "can't open file %s", file );
      ESCAPE;
    }
  }

  while( (cnt=fread(ibuf,1,16,ifil))!=0)
  {
    sprintf(obuf,"%8.08lX: ",filadr);
    for(p=ibuf,pp=strchr(obuf,0),b=cnt;b;b--,p++)
    {
      *pp++ = nibs[((*p)>>4)&0x0F];
      *pp++ = nibs[(*p)&0x0F];
      if(b>1) *pp++ = ' ';
    }
    if(cnt<16)
      for(b=(((16-cnt)*3)-1);b;b--)
        *pp++ = ' ';

    *pp++ = '\t';

    for(p=ibuf,b=cnt;b;b--)
    {
      *pp++ = (*p > 0x1F && *p < 0x7F ? *p : '.');
      p++;
    }
    *pp = 0;
    printf("%s\n",obuf);
    filadr += cnt;
  }
  if(ifil && ifil != stdin) {
    fclose(ifil);
  }
  result = 0;

FNC_XIT:

  return(result);
}

==> ytree-2.05.tar.gz: ytree-2.05/hex.c <==
/***************************************************************************
 *
 * View-Hex-Kommando-Bearbeitung
 *
 ***************************************************************************/


#include "ytree.h"



static int ViewHexFile(char *file_path);
static int ViewHexArchiveFile(char *file_path);



int ViewHex(char *file_path)
{
  switch( mode )
  {
    case DISK_MODE :
    case USER_MODE :     return( ViewHexFile( file_path ) );
    case TAPE_MODE : 
    case RPM_FILE_MODE : 
    case TAR_FILE_MODE : 
    case ZOO_FILE_MODE :
    case ZIP_FILE_MODE :
    case LHA_FILE_MODE :
    case ARC_FILE_MODE : return( ViewHexArchiveFile( file_path ) );
    default:             beep(); return( -1 );
  }
}




static int ViewHexFile(char *file_path)
{
  char *command_line;
  int  compress_method;
  int result = -1;

  if( access( file_path, R_OK ) )
  {
    (void) sprintf( message, 
		    "HexView not possible!*\"%s\"*%s", 
		    file_path, 
		    strerror(errno) 
		  );
    MESSAGE( message );
    ESCAPE;
  }

  InternalView(file_path);
  return(0);
  
  if( ( command_line = (char *)malloc( COMMAND_LINE_LENGTH + 1 ) ) == NULL )
  {
    ERROR_MSG( "Malloc failed*ABORT" );
    exit( 1 );
  }


  compress_method = GetFileMethod( file_path );


  if( compress_method == FREEZE_COMPRESS )
  {
    (void) sprintf( command_line, 
		    "%s < '%s' %s | %s | %s", 
		    MELT, 
		    file_path, 
		    ERR_TO_STDOUT,
		    HEXDUMP, 
		    PAGER 
		  );
  }
  else if( compress_method == COMPRESS_COMPRESS )
  {
    (void) sprintf( command_line, 
		    "%s < '%s' %s | %s | %s", 
		    UNCOMPRESS, 
		    file_path, 
		    ERR_TO_STDOUT,
		    HEXDUMP, 
		    PAGER 
		  );
  }
  else if( compress_method == GZIP_COMPRESS )
  {
    (void) sprintf( command_line, 
		    "%s < '%s' %s | %s | %s", 
		    GNUUNZIP, 
		    file_path, 
		    ERR_TO_STDOUT,
		    HEXDUMP, 
		    PAGER 
		  );
  }
  else
  {
    (void) sprintf( command_line, 
		    "%s '%s' | %s", 
		    HEXDUMP, 
		    file_path, 
		    PAGER 
		  );
  }
    
  
  if((result = SilentSystemCall( command_line )))
  {
    (void) sprintf( message, "can't execute*%s", command_line );
    MESSAGE( message );
  }

  free( command_line );

FNC_XIT:

  return( result );
}



static int ViewHexArchiveFile(char *file_path)
{
  char *command_line;
  char *archive;
  char buffer[80];
  int result = -1;

  if( ( command_line = (char *)malloc( COMMAND_LINE_LENGTH + 1 ) ) == NULL )
  {
    ERROR_MSG( "Malloc failed*ABORT" );
    exit( 1 );
  }

  (void) sprintf( buffer, "| %s | %s", HEXDUMP, PAGER );

  archive = (mode == TAPE_MODE) ? statistic.tape_name : statistic.login_path;

  MakeExtractCommandLine( command_line, 
			  archive,
			  file_path, 
			  buffer
			);

  if((result = SilentSystemCall( command_line )))
  {
    (void) sprintf( message, "can't execute*%s", command_line );
    MESSAGE( message );
  }

  free( command_line );

  return( result );
}
